#
# spec file for package xfce4-panel-plugin-weather
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin_name xfce4-weather-plugin
Name:           xfce4-panel-plugin-weather
Version:        0.9.1
Release:        lp151.1.1
Summary:        Weather Condition Monitoring Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
Url:            https://goodies.xfce.org/projects/panel-plugins/xfce4-weather-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{plugin_name}/0.9/%{plugin_name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM xfce4-panel-plugin-weather-fix-no-return-in-nonvoid-function.patch gber@opensuse.org -- Return bogus value in case of an unhandled switch case
Patch0:         xfce4-panel-plugin-weather-fix-no-return-in-nonvoid-function.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig(glib-2.0) >= 2.42
BuildRequires:  pkgconfig(gthread-2.0) >= 2.42
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.42
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(upower-glib)
# uses exo-open
Requires:       exo-tools
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}

%description
The Weather plugin shows short- and long-term weather forecasts.

%lang_package

%prep
%setup -q -n %{plugin_name}-%{version}
%patch0 -p1

%build
%configure --disable-static
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libweather.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{plugin_name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README TODO
%license COPYING
%{_libdir}/xfce4/panel/plugins/libweather.so
%{_datadir}/icons/hicolor/*/apps/xfce4-weather.*
%dir %{_datadir}/xfce4/weather
%{_datadir}/xfce4/weather/*
%{_datadir}/xfce4/panel/plugins/weather.desktop

%files lang -f %{name}.lang

%changelog
* Sat Mar 23 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 0.9.1
  * Use https for all connections (bxo#13645)
  * Use the latest sunrise API (2.0) (bxo#14972)
  * Use xfce_panel_plugin_get_icon_size so the weather icon respects the
    panel's configured icon size
  * Fix link to the met.no logo
  * Translation Updates
- Dropped obsolete macros
- Swtiched URL and Source to https://
* Mon Oct 15 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 0.9.0
  * Port to GTK+ 3
  - Preferences dialog ported to Glade
  - Replaced individual header includes
  - Replaced deprecated symbols
  - Replaced direct access with accessor functions
  - Improved forecast background with dark and light themes
  - Improved spacing in the preference and forecast dialogs
  - Added small (3px) padding between weather icon and scrollbox
  - Fixed full debug builds
  * Port to libsoup 2.42
  * Use HTTPS where possible
  * Translation updates
* Sat Nov 11 2017 seife+obs@b1-systems.com
- update to version 0.8.10
  - Set USER_AGENT for nominatim search (bxo#13877)
  - Fix showing times in UTC instead of local time on FreeBSD
    (bxo#13358)
  - Translation updates
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 0.8.9
  - Bump LocationforecastLTS version to 1.3
  - Fix compiler warnings about implicit function declarations
  - Change more URLs from http://yr.no to https://met.no
  - Translation updates
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 0.8.8
  - use https://api.met.no, old site has been deprecated
  - translation updates
  - Use met.no sunrise-1.1 API (bxo#12333)
- do not package huge ChangeLog file, NEWS is good enough
* Tue Jun 23 2015 gber@opensuse.org
- update to version 0.8.6
  - add ACLOCAL_AMFLAGS to Makefile.am
  - remove negative sign when temperature is rounded to 0 degree
    Fahrenheit (bug #11604)
  - fix IT_PROG_INTLTOOL warning
  - translation updates
* Tue Dec 23 2014 gber@opensuse.org
- update to version 0.8.5
  - translation updates
* Mon Nov  3 2014 gber@opensuse.org
- update to version 0.8.4
  - improve UI feedback when resetting weather data
  - show API deprecation warnings in the details tab of the summary
    window instead of the standard output
  - support upower-0.99
  - use locationforecastLTS-1.2 API
  - add code to handle proxy authentication
  - remove code dealing with laptop lid open/close
  - show astrodata in forecast day header tooltip in summary window
  - fetch and cache astronomical data for multiple days
  - add a button for opening/creating the user icon themes
    directory in the config dialog
  - sort icon themes by path names (user themes are listed first)
  - correct spelling of precipitation
  - context menu: Resolve mnemonic conflict for Refresh and Remove
    (bug #9911)
  - summary window: Fix clock not updating properly
  - fix wind direction translation
  - make using only a single row the default setting
  - better handle single row and icon size in various panel modes
  - fix text color not being remembered over restarts
  - build system cleanups and dependency bumps
  - many translation updates
- drop obsolete xfce4-panel-plugin-weather-upower-0.99.patch,
  xfce4-panel-plugin-weather-fix-panel-icon-size.patch,
  xfce4-panel-plugin-weather-use-locationforecast-1.2-api.patch
* Tue Oct 21 2014 gber@opensuse.org
- Add xfce4-panel-plugin-weather-fix-panel-icon-size.patch in order
  to fix the size of the panel icon (backported from upstream git)
- Add xfce4-panel-plugin-weather-use-locationforecast-1.2-api.patch
  Switch to met.no locationforecast-1.2 API (bxo#10916, bnc#901944,
  backported from upstream git)
* Tue Jun 10 2014 gber@opensuse.org
- Add xfce4-panel-plugin-weather-upower-0.99.patch in order to
  support upower >= 0.99 (backported from upstream git, bxo#10922)
* Tue Feb 19 2013 gber@opensuse.org
- update to version 0.8.3
  - replace internal HTTP implementation by libsoup; this gets the
    search dialog working again and makes the plugin future-proof
  - fix timezone issues by putting the plugin into the timezone of the
    chosen location
  - cache and interpolate data
  - possibly improves current weather
  - keeps plugin going for a while without internet connection
  - support icon themes (see README for using and creating themes!)
  - add brand new icon theme "Simplistic" by Simon Steinbeiß
  - add small variation of the "Liquid" theme for dark panels
  - improvements to existing icons
  - rework configuration dialog
  - settings are applied instantaneous
  - tooltips provide encyclopedic information about weather-related
    stuff, enhancing user-experience
  - the Location tab lets you tweak latitude, longitude, altitude and
    timezone (autodetection powered by GeoNames)
  - the Units page does away with the insufficient imperial/metric
    checkbox and empowers you to choose the units used in your
    country
  - useful appearance tweaks
  - improve the scrollbox (font, color, multiple lines)
  - add new (calculated) values: dew point and apparent temperature
  - optimize CPU usage and power-save mode using upower
  - improve download handling and widget updates
  - improve UI feedback by making the main plugin container a panel
    toggle button
  - improve support for RTL languages
  - many translation updates
  - update README with important and useful information
- added
  xfce4-panel-plugin-weather-fix-no-return-in-nonvoid-function.patch
  which returns a bogus value in case of an unhandled switch case
* Wed Sep 12 2012 gber@opensuse.org
- update to version 0.8.2
  - lots of translations updates
  - update liquid icon set to be complete
  - improve sleet icons
  - improve rain icons for darker panels
  - correct symbol descriptions and add comments with explanations
  - correct and improve liquid icons
  - updated README with documentation from Xfce Goodies homepage
  - add debugging code and instructions on how to debug in README
  - add section about theming and icon sets in README
  - remove code for now unsupported GTK/GLIB versions
  - bump minimum requirements to match Xfce-4.8 (yes, they were
    needed before) and drop some legacy code
  - fix ugly GDK_WINDOW assertion when opening the summary window
  - clear scrollbox labels before updating conditions
  - correct "Astrological data" to "Astronomical data"
  - variable name fix for Solaris
  - fix crash in summary window when something weird happens
  - some more code refactoring, clean up and minor fixes
- dropped obsolete
  xfce4-panel-plugin-weather-fix-crash-when-no-data.patch
* Tue Aug  7 2012 gber@opensuse.org
- added xfce4-panel-plugin-weather-fix-crash-when-no-data.patch in
  order to fix a crash in summary window when data is not available
  (bxo#9182)
* Mon Aug  6 2012 gber@opensuse.org
- update to version 0.8.1
  - show more information in panel plugin tooltip
  - tooltip for location name in config dialog now shows latitude
    and longitude, or clearer instructions what to do
  - fetch sunrise/sunset times via met.no webservice; this way we
    get moon phase, moonrise and moonset for free
  - better handling of sanitizing location name
  - correct texts in search dialog
  - set text color on alternate cells in forecast table
  - bump minimum requirements to Xfce 4.6
  - build the plugin as a module
  - fix many smaller bugs like uninitialized, unused variables etc
  - reformat and cleanup source code, improve code quality
  - translation updates
- dropped obsolete
  xfce4-panel-plugin-weather-remove-dependency-on-glib-2.30.patch
- updated description
* Tue Jul 24 2012 gber@opensuse.org
- update to version 0.8.0
  - Migrate to libxfce4ui.
  - Better handling of vertical and deskbar modes.
  - Fix adjusting label text size to panel size.
  - Fix scrollbox scroll direction in vertical mode.
  - Major rewrite: Migrate to yr.no API instead of weather.com
    The plugin now uses data from the Norwegian Meteorological
    Institute, which is a bit different and forced a redesign of
    the summary window and more logic for computing the values.
    This rewrite means the hassle with the expiring license keys is
    finally gone, and the plugin shouldn't stop working suddenly,
    as API changes are announced quite some time before they become
    active. Forecasts for up to 10 days are provided, depending on
    the location. The location is defined by latitude and
    longitude, the actual name is only used for presentation.
  - Switch to the new GeoIP service at geoip.xfce.org, the old one
    has stopped working correctly quite some time ago.
  - Automatically set system of measurement depending on the GeoIP
    country code.
  - Fix wrong location search results
  - Enlarge the search dialog. It's now capable of showing 10 or
    more results instead of only 2 or 3.
  - Nice error message in summary window when no location was set
    or when there's no data available.
  - Make left click toggle the forecast window.
  - Optimized update intervals (downloading data and presentation).
    This should also fix update issues after suspend/resume.
  - Add move label up/down buttons to config dialog.
  - Add shortcuts to the widgets in the config dialog.
  - Add shortcuts for accessing the notebook pages in the forecast
    window.
  - Fix compilation warnings, possible null pointer errors, memory
    leaks, hardcoded values, make more strings translatable.
- added
  xfce4-panel-plugin-weather-remove-dependency-on-glib-2.30.patch
  in order to remove the dependency on glib-2.30
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
